==> openjdk-11_11.0.4+11.orig.tar.xz: openjdk-11-11.0.4+11/src/hotspot/share/jfr/leakprofiler/chains/rootSetClosure.hpp <==
/*
 * Copyright (c) 2014, 2018, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 *
 */

#ifndef SHARE_VM_JFR_LEAKPROFILER_CHAINS_ROOTSETCLOSURE_HPP
#define SHARE_VM_JFR_LEAKPROFILER_CHAINS_ROOTSETCLOSURE_HPP

#include "memory/iterator.hpp"
#include "oops/oop.hpp"

class EdgeQueue;

class RootSetClosure: public BasicOopIterateClosure {
 private:
  RootSetClosure(EdgeQueue* edge_queue);
  EdgeQueue* _edge_queue;
  void closure_impl(const oop* reference, const oop pointee);
 public:
  static void add_to_queue(EdgeQueue* edge_queue);
  static void process_roots(OopClosure* closure);

  virtual void do_oop(oop* reference);
  virtual void do_oop(narrowOop* reference);
};

#endif // SHARE_VM_JFR_LEAKPROFILER_CHAINS_ROOTSETCLOSURE_HPP

==> openjdk-13_13~13.orig.tar.xz: openjdk-13-13~13/src/hotspot/share/jfr/leakprofiler/chains/rootSetClosure.hpp <==
/*
 * Copyright (c) 2014, 2019, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 *
 */

#ifndef SHARE_JFR_LEAKPROFILER_CHAINS_ROOTSETCLOSURE_HPP
#define SHARE_JFR_LEAKPROFILER_CHAINS_ROOTSETCLOSURE_HPP

#include "memory/iterator.hpp"
#include "oops/oop.hpp"

class EdgeQueue;

class RootSetClosure: public BasicOopIterateClosure {
 private:
  RootSetClosure(EdgeQueue* edge_queue);
  EdgeQueue* _edge_queue;
  void closure_impl(const oop* reference, const oop pointee);
 public:
  static void add_to_queue(EdgeQueue* edge_queue);
  static void process_roots(OopClosure* closure);

  virtual void do_oop(oop* reference);
  virtual void do_oop(narrowOop* reference);
};

#endif // SHARE_JFR_LEAKPROFILER_CHAINS_ROOTSETCLOSURE_HPP
